% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: Iowa.d,v 1.3 1999/12/01 05:07:43 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{Iowa}
\alias{Iowa}
\title{The Iowa Wheat Yield Data}
\description{
  The data gives the pre-season and three growing months' precipitation,
  the mean temperatures for the three growing months and harvest month,
  the year, and the yield of wheat for the USA state of Iowa, for the
  years 1930--1962.
}
\usage{
data(Iowa)
}
\format{
  The data frame has the following components:
  \describe{
    \item{\code{Year}}{Year of measurement (surrogate for variety improvements)}
    \item{\code{Rain0}}{Pre-season rainfall (in.)}
    \item{\code{Temp1}}{Mean temperature for the first growing month (deg. F)}
    \item{\code{Rain1}}{Rainfall for the first growing month (in.)}
    \item{\code{Temp2}}{Mean temperature for the second growing month (deg. F)}
    \item{\code{Rain2}}{Rainfall for the second growing month (in.)}
    \item{\code{Temp3}}{Mean temperature for the third growing month (deg. F)}
    \item{\code{Rain3}}{Rainfall for the third growing month (in.)}
    \item{\code{Temp4}}{Mean temperature for the harvest month (deg. F)}
    \item{\code{Yield}}{Yield of wheat in Iowa for the given year (bush./acre)}
  }
}
\section{CATEGORY}{
Multiple regression; diagnostics.
}
\source{
  CAED Report, 1964.  Quoted in Draper and Smith, Applied Regression
  Analysis.
}
\examples{
data(Iowa)
pairs(Iowa)
}
\keyword{datasets}
% Converted by Sd2Rd version 1.21.

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: Prostate.d,v 1.4 1999/12/01 05:07:34 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{Prostate}
\alias{Prostate}
\title{Prostate Cancer Data}
\description{
  These data come from a study that examined the correlation between the
  level of prostate specific antigen and a number of clinical measures
  in men who were about to receive a radical prostatectomy.  It is data
  frame with 97 rows and 9 columns.
}
\usage{
data(Prostate)
}
\format{
  The data frame has the following components:
  \describe{
    \item{\code{lcavol}}{log(cancer volume)}
    \item{\code{lweight}}{log(prostate weight)}
    \item{\code{age}}{age}
    \item{\code{lbph}}{log(benign prostatic hyperplasia amount)}
    \item{\code{svi}}{seminal vesicle invasion}
    \item{\code{lcp}}{log(capsular penetration)}
    \item{\code{gleason}}{Gleason score}
    \item{\code{pgg45}}{percentage Gleason scores 4 or 5}
    \item{\code{lpsa}}{log(prostate specific antigen)}
  }
}
\source{
  Stamey, T.A., Kabalin, J.N., McNeal, J.E., Johnstone, I.M., Freiha,
  F., Redwine, E.A. and Yang, N. (1989)\cr
  Prostate specific antigen in the diagnosis and treatment of
  adenocarcinoma of the prostate: II. radical prostatectomy treated
  patients,
  \emph{Journal of Urology} \bold{141}(5), 1076--1083.
}
\examples{
data(Prostate)
attach(Prostate)
pairs(Prostate, col = 1+svi, pch = gleason - 5,
      main = paste("Prostate data, n = ", nrow(Prostate)))
detach()

l1c.P <- l1ce(lcavol ~ ., data = Prostate)
coef(l1c.P)[coef(l1c.P) != 0] ## only age, lcp, lpsa (+ intercept)
summary(l1c.P)
}
\keyword{datasets}
% Converted by Sd2Rd version 1.21.

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: [[.l1celist.d,v 1.1 1998/09/18 11:23:09 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{[.l1celist}
\alias{[.l1celist}
\alias{[[.l1celist}
\title{Subscript a `l1celist' Object}
\description{
  Allows the user to extract values from a \code{l1celist} object by using
  subscripts.
}
\usage{
x[i, drop]
x[[i]]
}
\arguments{
  \item{x}{an object inheriting from class \code{"l1celist"}.}
  \item{i}{subscripts applying to elements (fitted models) in the list.}
  \item{drop}{logical defaulting to \code{TRUE}.  If only one model is
    subscribed, then it is returned as an object of class \code{"l1ce"}.
    If \code{drop=F}, then an object of class \code{"l1celist"} is
    always returned.}
}
\value{
  an object of class \code{"l1celist"} or class \code{"l1ce"}
  extracted from the original list.
}
\keyword{manip}
% Converted by Sd2Rd version 1.21.

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: coef.l1ce.d,v 1.5 1999/12/01 05:08:40 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{coef.l1ce}
\alias{coef.l1ce}
\title{Coefficients of an `l1ce' Object}
\usage{
\method{coef}{l1ce}(object, all=TRUE, constrained=FALSE, \dots)
}
\description{
%% For R >= 1.9.0, replace  \link{   by   \link[stats]{:
  This is a method for \code{\link{coef}()} for objects inheriting from
  class \code{l1ce}.  See \code{\link{coef}} for the general behavior of
  this function and for the interpretation of \code{object}.
}
\arguments{
  \item{object}{an object of class \code{l1ce}, see help on
    \code{\link{l1ce.object}}.}
  \item{all}{logical; if false, then only the non-zero coefficients are
    returned.}
  \item{constrained}{logical; if true, then only the coefficients that
    were constrained are returned.}
  \item{\dots}{possibly further arguments (none at the moment).}
}
\keyword{regression}
\keyword{models}

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: coef.l1celist.d,v 1.4 1999/12/01 05:08:55 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{coef.l1celist}
\alias{coef.l1celist}
\title{Coefficients of an `l1celist' Object}
\usage{
\method{coef}{l1celist}(object, all=TRUE, constrained=FALSE, \dots)
}
\description{
%% For R >= 1.9.0, replace  \link{   by   \link[stats]{:
  This is a method for \code{\link{coef}()} for objects inheriting from
  class \code{l1celist}.  See \code{\link{coef}} for the general behavior of
  this function and for the interpretation of \code{object}.
}
\arguments{
  \item{object}{an object of class \code{l1celist}, see help on
    \code{\link{l1celist.object}}.}
  \item{all}{logical; if false, then the coefficients that are zero in
    all fitted models of the list are not returned.}
  \item{constrained}{logical; if true, then only the coefficients that
    were constrained are returned.}
  \item{\dots}{possibly further arguments (none at the moment).}
}
\keyword{regression}
\keyword{models}

\eof
\name{deviance.gl1ce}
\alias{deviance.gl1ce}
\title{Deviance Method for `gl1ce' Objects}
\usage{
deviance.gl1ce(object, \dots)
}
\description{
  This is a method of the generic function \code{\link{deviance}()} for
  objects inheriting from class \code{gl1ce} (see
  \code{help(\link{gl1ce.object})}).
}
\arguments{
  \item{object}{an object inheriting from class \code{gl1ce}.}
  \item{\dots}{possibly further arguments (none at the moment).}
}
\seealso{\code{\link{deviance}} for the general
  behavior of this function and for the interpretation of \code{object}.
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
\name{deviance.l1ce}
\alias{deviance.l1ce}
\alias{deviance.l1celist}
\title{Deviance Method for `l1ce' and `l1celist' Objects}
\usage{
deviance.l1ce(object, \dots)
deviance.l1celist(object, \dots)
}
\arguments{
  \item{object}{an object inheriting from class \code{l1ce} or
    \code{l1celist}, respectively.}
  \item{\dots}{possibly further arguments (none at the moment).}
}
\description{
  These are methods of the generic function \code{\link{deviance}()} for
  objects inheriting from class \code{l1ce} or \code{l1celist} (see
  \code{help(\link{l1ce.object})} and \code{help(\link{l1celist.object})}).
}
\seealso{\code{\link{deviance}} for the general
  behavior of this function and for the interpretation of \code{object}.
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
\name{fitted.l1ce}
\alias{fitted.l1ce}
\alias{fitted.l1celist}
\title{Fitted Values for `l1ce', `l1celist' and `gl1ce' Objects}
\description{
  These are methods of the generic function \code{\link{fitted}()} for
  objects inheriting from class \code{l1ce} or \code{l1celist} (see
  \code{help(\link{l1ce.object})} and \code{help(\link{l1celist.object})}).
}
\usage{
fitted.l1ce(object, \dots)
fitted.l1celist(object, \dots)
}
\arguments{
  \item{object}{an object inheriting from class \code{l1ce} or
    \code{l1celist}, e.g., an \code{gl1ce} one (see
    \code{\link{gl1ce.object}}).}
  \item{\dots}{further potential arguments passed to methods.}
}
\seealso{\code{\link{fitted}} for the general
  behavior of this function and for the interpretation of \code{object}.
}
\keyword{models}

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: gcv.d,v 1.2 1998/09/18 07:03:35 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{gcv}
\alias{gcv}
\title{Generalised Cross-Validation Score}
}
\description{
  Extracts the generalised cross-validation score(s) from fitted
  model objects.
}
\usage{
gcv(object, \dots)
}
\arguments{
  \item{object}{fitted model object; see gcv methods for details.}
  \item{\dots}{arguments passed to methods.}
}
\value{
  A vector (or matrix) with the bound(s) (relative [if used] and absolute),
  the Lagrangian(s) and the generalised cross-validation score(s) for
  the fitted model(s).
}
\details{
  See documentation.
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: gcv.l1ce.d,v 1.4 1999/12/01 05:10:52 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{gcv.l1ce}
\alias{gcv.l1ce}
\alias{gcv.l1celist}
\title{`gcv()' Methods for `l1ce' and `l1celist' Objects.}
\usage{
\method{gcv}{l1ce}(object, type = c("OPT", "Tibshirani"),
    gen.inverse.diag = 0, \dots)
\method{gcv}{l1celist}(object, type = c("OPT", "Tibshirani"),
    gen.inverse.diag = 0, \dots)
}
\arguments{
  \item{object}{an object of class \code{l1ce} or \code{l1celist}.}
  \item{type}{character (string) indicating whether to use the
    covariance formula of Osborne, Presnell and Turlach or the formula
    of Tibshirani.}
  \item{gen.inverse.diag}{
    if Tibshirani's formula for the covariance matrix is used, this value
    is used for the diagonal elements of the generalised inverse that
    appears in the formula that corresponds to parameters estimated to be
    zero.  The default is 0, i.e. use the Moore-Penrose inverse.
    Tibshirani's code uses \code{gen.inverse.diag = 1e11}.}
  \item{\dots}{further potential arguments passed to methods.}
}
\description{
  This is a method for the function \code{gcv()} for objects inheriting
  from class \code{l1ce} or \code{l1celist}.
}
\seealso{
  \code{\link{gcv}} for the general behavior of this function;
  \code{\link{l1ce.object}} and \code{\link{l1celist.object}} for
  description of the \code{object} argument.
}
\details{
See documentation.
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
\name{gl1ce}
\alias{gl1ce}
\alias{family.gl1ce}
\title{Generalized Regression With L1-constraint on the Parameters}
}
\description{
  Fit a generalized regression problem while imposing an L1 constraint on
  the parameters.  Returns an object of class \code{gl1ce}.
}
\usage{
gl1ce(formula, data = sys.parent(), weights, subset, na.action,
      family = gaussian, control = glm.control(\dots), sweep.out = ~ 1,
      x = FALSE, y = TRUE, contrasts = NULL, standardize = TRUE,
      guess.constrained.coefficients = double(p), bound = 0.5, \dots)
\method{family}{gl1ce}(object, \dots)
}
\arguments{
  \item{formula}{a \code{\link{formula}}, with the response on the left
    hand side of a \code{~} operator, and the terms, separated by a
    \code{+} operator, on the right hand side.}
  \item{data}{a \code{\link{data.frame}} in which to interpret the
    variables named in the formula, the \code{weights}, the
    \code{subset} and the \code{sweep.out} argument.  If this is
    missing, then the variables in the formula should be globally
    available.}
  \item{weights}{vector of observation weights.  The length of
    \code{weights} must be the same as the number of observations.  The
    weights must be strictly positive, since zero weights are ambiguous,
    compared to use of the \code{subset} argument.}
  \item{subset}{
    expression saying which subset of the rows of the data should be used in the
    fit.  This can be a logical vector (which is replicated to have length equal
    to the number of observations), or a numeric vector indicating which
    observation numbers are to be included, or a character vector of the
    row names to be included.  All observations are included by default.
  }
  \item{na.action}{
    a function to be applied to the \code{model.frame} after any
    \code{subset} argument has been used.  The default (with
    \code{na.fail}) is to create an error if any missing values are
    found.  A possible alternative is \code{na.omit}, which deletes
    observations that contain one or more missing values.
  }
  \item{family}{a \code{\link{family}} object - a list of functions and
    expressions for defining the link and variance functions,
    initialization and iterative weights.  Families supported are
    gaussian, binomial, poisson, Gamma, inverse.gaussian and quasi.
    Functions like binomial produce a family object, but can be given
    without the parentheses.  Family functions can take arguments, as in
    \code{binomial(link=probit)}.
  }
  \item{control}{
    a list of iteration and algorithmic  constants.  See glm.control for their
    names and default values.  These can also be set as arguments to gl1ce itself.
  }
  \item{sweep.out}{
    a formula object, variables whose parameters are not put under the
    constraint are swept out first.  The variables should appear on the
    right of a \code{~} operator and be separated by \code{+} operators.  Default is
    \code{~1}, i.e. the constant term is not under the constraint.  If this
    parameter is \code{NULL}, then all parameters are put under the constraint.
  }
  \item{x}{
    logical flag: if \code{TRUE}, the model matrix is returned in component \code{x}.
  }
  \item{y}{
    logical flag: if \code{TRUE}, the response is returned in component \code{y}.
  }
  \item{contrasts}{
    a list giving contrasts for some or all of the factors appearing in the model
    formula. The elements of the list should have the same name as the variable
    and should be either a contrast matrix (specifically, any full-rank
    matrix with as many rows as there are levels in the factor),
    or else a function to compute such a matrix given the number of levels.
  }
  \item{standardize}{
    logical flag: if \code{TRUE}, then the columns of the model matrix that
    correspond to parameters that are constrained are standardized to have
    empirical variance one.  The standardization is done after taking
    possible weights into account and after sweeping out variables whose
    parameters are not constrained.
  }
  \item{guess.constrained.coefficients}{
    initial guess for the parameters that are constrained.
  }
  \item{bound}{numeric, either a single number or a vector: the
    constraint(s) that is/are put onto the L1 norm of the parameters.}
  \item{\dots}{potential arguments for \code{\link[base]{glm.control}},
    as default for the \code{control} argument above.}
  \item{object}{an \R object of class \code{"gl1ce"}.}
}% args
\value{
  an object of class \code{gl1ce} is returned by \code{gl1ce()}.
  See \code{\link{gl1ce.object}} for details.
}
\references{
  See the references in \code{\link{l1ce}}.

  Justin Lokhorst (1999).
  The LASSO and Generalised Linear Models,
  Honors Project, Nov.1999, Dept.Statist., Univ. of Adelaide.
  Available as file \file{Doc/justin.lokhorst.ps.gz} in both shar files
  from \url{http://www.maths.uwa.edu.au/~berwin/software/lasso.html}.
}
\seealso{\code{\link{glm}} for unconstrained generalized regression
  modeling.
}
\examples{
## example from base:
data(esoph)
summary(esoph)
## effects of alcohol, tobacco and interaction, age-adjusted
modEso <- formula(cbind(ncases, ncontrols) ~ agegp + tobgp * alcgp)
glm.E   <- glm(modEso, data = esoph, family = binomial())
gl1c.E <- gl1ce(modEso, data = esoph, family = binomial())
gl1c.E
plot(residuals(gl1c.E) ~ fitted(gl1c.E))

sg1c <- summary(gl1c.E)
sg1c

## Another comparison  glm() / gl1c.E:
plot(predict(glm.E,  type="link"), predict(glm.E,  type="response"),
     xlim = c(-3,0))
points(predict(gl1c.E, type="link"), predict(gl1c.E, type="response"),
       col = 2, cex = 1.5)

%%% mabye FIXME!!
labels(gl1c.E)#-- oops! empty!!
}
\keyword{models}
\keyword{optimize}
\keyword{regression}
% Converted by Sd2Rd version 1.21.

\eof
\name{gl1ce.object}
\alias{gl1ce.object}
\title{Generalized L1 Constrained Estimation Model Object}
\description{
  These are objects of class \code{gl1ce}
  They represent the fit of a generalized regression model under an L1
  constraint on (some of) the parameters.
}
\section{GENERATION}{
  This class of objects is returned from the \code{gl1ce} function
  to represent a fitted model.
}
\section{METHODS}{
The \code{gl1ce} class of objects has methods for the following generic
functions:
\code{deviance}, \code{predict}, \code{print}, \code{residuals}, \code{summary}.  Other generic
functions are inherited from the class \code{l1ce}.
}
\section{STRUCTURE}{
The following components must be included in a legitimate \code{gl1ce} object.
\item{coefficients}{
the coefficients of the fit of the response to the columns of the model matrix.
The names of the coefficients are the names of the columns of the model matrix.
}
\item{residuals}{
the residuals from the fit.
If weights were used, then the residuals are the raw residuals - the
weights are not taken into account.
If you need residuals that all have the same variance, then use the
\code{residuals} function with \code{type="pearson"}.
}
\item{fitted.values}{
  the fitted values from the fit.  If weights were used, the fitted
  values are not adjusted for the weights.
}
\item{family}{
  the family of which the fitted regression model belongs, eg.,
  \code{\link{binomial}(link=probit)}.
}
\item{bound}{
  the (absolute) L1 constraint imposed on the parameters.
}
\item{Lagrangian}{
the value of the Lagrangian that enforces the constraint at the solution.
}
\item{xtx}{
the moment matrix of the variables that are under the constraint.
(After taking weights, sweep-out variables and standardization into
account).
}
\item{xtr}{
the product of the design matrix of the variables that are under the
constraint (after taking weights, sweep-out variables and
standardization into account) with the residual vector.
}
\item{constrained.coefficients}{
the coefficients on the scale on which they are constrained.  Useful
as initial value for further fits.
}
\item{sweep.out}{
information on the variables that are not under the constraint and on
which the other variables and the response is projected first.
Optional, not present if \code{sweep.out = NULL}.
}
\item{assign}{
the list of assignments of coefficients (and effects) to the terms in
the model.
The names of this list are the names of the terms.
The \code{i}th element of the list is the vector saying which coefficients
correspond to the \code{i}th term.
It may be of length 0 if there were no estimable effects for the term.
See also \code{R.assign} below.
}
\item{terms}{
an object of mode \code{expression} and class \code{term} summarizing the formula.
Used by various methods, but typically not of direct relevance to users.
}
\item{call}{
an image of the call that produced the object, but with the arguments
all named and with the actual formula included as the formula argument.
}
\item{contrasts}{
a list containing sufficient information to construct the contrasts
used to fit any factors occurring in the model.
The list contains entries that are either matrices or character vectors.
When a factor is coded by contrasts, the corresponding contrast matrix
is stored in this list.
Factors that appear only as dummy variables and variables in the model
that are matrices correspond to character vectors in the list.
The character vector has the level names for a factor or the column
labels for a matrix.
}
\item{x}{
optionally the model matrix, if \code{x=T}.
}
\item{y}{
optionally the response, if \code{y=T}.
}}
\details{
The residuals, fitted values, coefficients, and effects should be extracted
by the generic functions of the same name, rather than
by the \code{$} operator.
}
\seealso{
\code{\link{gl1ce}}, \code{\link{coefficients}}.
}
\keyword{classes}
\keyword{regression}
\keyword{methods}
% Converted by Sd2Rd version 1.21.



\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: is.formula.d,v 1.2 1999/12/01 05:12:09 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{is.formula}
\alias{is.formula}
\title{Tests for Formula Objects}
\usage{
is.formula(x)
}
\arguments{
  \item{x}{an \R object to be tested.}
}
\description{
  \code{is.formula} returns \code{TRUE} if \code{x} is an object of
  class \code{"formula"}, and \code{FALSE} otherwise.
}
\keyword{utilities}

\eof
\name{l1ce}
\alias{l1ce}
\title{Regression Fitting With L1-constraint on the Parameters}
\description{
  Returns an object of class \code{"l1ce"} or \code{"licelist"} that represents
  fit(s) of linear models while imposing L1 constraint(s) on the parameters.
}
\usage{
l1ce(formula, data = sys.parent(), weights, subset, na.action,
     sweep.out = ~ 1, x = FALSE, y = FALSE,
     contrasts = NULL, standardize = TRUE,
     trace = FALSE, guess.constrained.coefficients = double(p),
     bound = 0.5, absolute.t = FALSE)
}
\arguments{
  \item{formula}{a formula object, with the response on the left of a
    \code{ ~ } operator, and the terms, separated by \code{+} operators,
    on the right.}
  \item{data}{
    a \code{data.frame} in which to interpret the variables named in the
    formula, the \code{weights}, the \code{subset} and the
    \code{sweep.out} argument.  If this is missing, then the variables
    in the formula should be globally available.}
  \item{weights}{
    vector of observation weights.  The length of \code{weights} must be
    the same as the number of observations.  The weights must be
    nonnegative and it is strongly recommended that they be strictly
    positive, since zero weights are ambiguous, compared to use of the
    \code{subset} argument.
  }
  \item{subset}{
    expression saying which subset of the rows of the data should be
    used in the fit.  This can be a logical vector (which is replicated
    to have length equal to the number of observations), or a numeric
    vector indicating which observation numbers are to be included, or a
    character vector of the row names to be included.  All observations
    are included by default.
  }
  \item{na.action}{
    a function to filter missing data.  This is applied to the
    \code{\link{model.frame}} after any \code{subset} argument has been used.
    The default (with \code{na.fail}) is to create an error if any
    missing values are found.  A possible alternative is \code{na.omit},
    which deletes observations that contain one or more missing values.
  }
  \item{sweep.out}{
    a formula object, variables whose parameters are not put under the
    constraint are swept out first.  The variables should appear on the
    right of a \code{ ~ } operator and be separated by \code{+} operators.
    Default is \code{ ~1 }, i.e. the constant term is not under the
    constraint.  If this parameter is \code{NULL}, then all parameters
    are put under the constraint.
  }
  \item{x}{logical indicating if the model matrix should be returned in
    component \code{x}.}
  \item{y}{logical indicating if the response should be returned in
    component \code{y}.}
  \item{contrasts}{
    a list giving contrasts for some or all of the factors
    appearing in the model formula.
    The elements of the list should have the same name as the variable
    and should be either a contrast matrix (specifically, any full-rank
    matrix with as many rows as there are levels in the factor),
    or else a function to compute such a matrix given the number of levels.
  }
  \item{standardize}{
    logical flag: if \code{TRUE}, then the columns of the model matrix that
    correspond to parameters that are constrained are standardized to have
    emprical variance one.  The standardization is done after taking
    possible weights into account and after sweeping out variables whose
    parameters are not constrained.
  }
  \item{trace}{
    logical flag: if \code{TRUE}, then the status during each iteration of
    the fitting is reported.
  }
  \item{guess.constrained.coefficients}{
    initial guess for the parameters that are constrained.
  }
  \item{bound}{numeric, either a single number or a vector: the
    constraint(s) that is/are put onto the L1 norm of the parameters.}
  \item{absolute.t}{
    logical flag: if \code{TRUE}, then \code{bound} is an absolute bound and
    all entries in \code{bound} can be any positive number.  If
    \code{FALSE}, then \code{bound} is a relative bound and all entries
    must be between 0 and 1.}
}
\value{
  an object of class \code{l1ce} (if \code{bound} was a single value) or
  \code{l1celist} (if \code{bound} was a vector of values) is returned.
  See \code{\link{l1ce.object}} and \code{\link{l1celist.object}} for details.
}
\references{
  Osborne, M.R., Presnell, B. and Turlach, B.A. (2000)
  On the LASSO and its Dual,
  \emph{Journal of Computational and Graphical Statistics}
  \bold{9}(2), 319--337.

  Tibshirani, R. (1996)
  Regression shrinkage and selection via the lasso,
  \emph{Journal of the Royal Statistical Society, Series B}
  \bold{58}(1), 267--288.
}
\examples{
data(Iowa)
l1c.I <- l1ce(Yield ~ ., Iowa, bound = 10, absolute.t=TRUE)
l1c.I

## The same, printing information in each step:
l1ce(Yield ~ ., Iowa, bound = 10, trace = TRUE, absolute.t=TRUE)

data(Prostate)
l1c.P <- l1ce(lpsa ~ ., Prostate, bound=(1:30)/30)
length(l1c.P)# 30 l1ce models
l1c.P # -- MM: too large; should do this in summary(.)!
%% summary(l1c.P)
\testonly{
str(l1c.P, max.lev = 1)
}

plot(resid(l1c.I) ~ fitted(l1c.I))
abline(h = 0, lty = 3, lwd = .2)
}
\keyword{models}
\keyword{optimize}
\keyword{regression}
% Converted by Sd2Rd version 1.21.

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: l1ce.object,v 1.2 1998/09/20 09:28:27 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{l1ce.object}
\alias{l1ce.object}
\title{L1 Constrainted Estimation Model Object}
\description{
  These are objects of class \code{"l1ce"}.
  They represent the fit of a regression model under an L1 constraint on
  (some of) the parameters.
}
\section{GENERATION}{
  This class of objects is returned from the \code{\link{l1ce}} function
  to represent a fitted model.
}
\section{METHODS}{
  The \code{"l1ce"} class of objects has methods for the following generic
  functions:\cr
  \code{coef}, \code{deviance}, \code{fitted}, \code{formula},
  \code{gcv}, \code{labels}, \code{predict}, \code{print},
  \code{residuals}, \code{summary}, \code{vcov}.
}
\section{STRUCTURE}{
  The following components must be included in a legitimate \code{l1ce} object.
  \describe{
    \item{coefficients}{
      the coefficients of the fit of the response to the columns of the model
      matrix.  The names of the coefficients are the names of the columns
      of the model matrix.
    }
    \item{residuals}{
      the residuals from the fit.
      If weights were used, then the residuals are the raw residuals - the
      weights are not taken into account.
      If you need residuals that all have the same variance, then use the
      \code{residuals} function with \code{type="pearson"}.
    }
    \item{fitted.values}{
      the fitted values from the fit.
      If weights were used, the fitted values are not adjusted for the weights.
    }
    \item{bound}{the (absolute) L1 constraint imposed on the parameters.    }
    \item{relative.bound}{
      optional, the (relative) L1 constraint imposed on the parameters.
      Present if \code{absolute.t=F}.
    }
    \item{Lagrangian}{
      the value of the Lagrangian that enforces the constraint at the
      solution.
    }
    \item{xtx}{
      the moment matrix of the variables that are under the constraint.
      (After taking weights, sweep-out variables and standardization into
      account).
    }
    \item{xtr}{
      the product of the design matrix of the variables that are under the
      constraint (after taking weights, sweep-out variables and
      standardization into account) with the residual vector.
    }
    \item{constrained.coefficients}{
      the coefficients on the scale on which they are constrained.  Useful
      as initial value for further fits.
    }
    \item{sweep.out}{
      Optional information on the variables that are not under the
      constraint and on which the other variables and the response is
      projected first.%% FIXME?? isn't this needed by summary?
      Optional, not present if \code{sweep.out = NULL}.
    }
    \item{assign}{
      the list of assignments of coefficients (and effects) to the terms in
      the model.
      The names of this list are the names of the terms.
      The \code{i}th element of the list is the vector saying which coefficients
      correspond to the \code{i}th term.
      It may be of length 0 if there were no estimable effects for the term.
      See also \code{R.assign} below.
    }
    \item{terms}{%% FIXME : differs between R and S+
      an object of mode \code{expression} and class \code{term}
      summarizing the formula.  Used by various methods, but typically
      not of direct relevance to users.
    }
    \item{call}{
      an image of the call that produced the object, but with the arguments
      all named and with the actual formula included as the formula argument.
    }
    \item{contrasts}{
      a list containing sufficient information to construct the contrasts
      used to fit any factors occurring in the model.
      The list contains entries that are either matrices or character vectors.
      When a factor is coded by contrasts, the corresponding contrast matrix
      is stored in this list.
      Factors that appear only as dummy variables and variables in the model
      that are matrices correspond to character vectors in the list.
      The character vector has the level names for a factor or the column
      labels for a matrix.
    }
    \item{x}{optionally the model matrix, if \code{x=TRUE}.}
    \item{y}{optionally the response, if \code{y=TRUE}.}
  }%describe
}
\details{
  The residuals, fitted values, coefficients, and effects should be extracted
  by the generic functions of the same name, rather than
  by the \code{$} operator.
}
\seealso{
  \code{\link{l1ce}}, \code{\link{coefficients}}.
}
\keyword{classes}
\keyword{regression}
\keyword{methods}
% Converted by Sd2Rd version 1.21.

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: l1celist.object.d,v 1.2 1998/09/23 02:55:04 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{l1celist.object}
\alias{l1celist.object}
\title{Object of Several L1 Constrained Estimation Models}
\description{
These are objects of class \code{"l1celist"}
They represent the fits of several regression models under an L1
constraint on (some of the parameters).
}
\section{GENERATION}{
This class of objects is returned from the \code{l1ce} function
to represent a fitted model.
}
\section{METHODS}{
The \code{"l1celist"} class of objects has methods for the following generic
functions:
\code{[}, \code{[[}, \code{aux}, \code{coef}, \code{deviance}, \code{fitted}, \code{formula}, \code{gcv},
\code{labels}, \code{plot}, \code{print}, \code{residuals}, \code{vcov}.
}
\section{STRUCTURE}{
An object of class \code{l1celist} is a list of lists.  Each component of
the list is a list with the information of an object of class \code{l1ce}
that is unique for that information.  All shared information is stored
as attributes.


Each component of the list must include the following components
for it to be a legitimate \code{l1celist} object.
\item{coefficients}{
the coefficients of the fit of the response to the
columns of the model
matrix.
The names of the coefficients are the names of the
columns of the model matrix.
}
\item{residuals}{
the residuals from the fit.
If weights were used, then the residuals are the raw residuals - the
weights are not taken into account.
If you need residuals that all have the same variance, then use the
\code{residuals} function with \code{type="pearson"}.
}
\item{fitted.values}{
the fitted values from the fit.
If weights were used, the fitted values are not adjusted for the weights.
}
\item{bound}{
the (absolute) L1 constraint imposed on the parameters.
}
\item{relative.bound}{
optional, the (relative) L1 constraint imposed on the parameters.
Present if \code{absolute.t=F}.
}
\item{Lagrangian}{
the value of the Lagrangian that enforces the constraint at the
solution.
}
\item{xtr}{
the product of the design matrix of the variables that are under the
constraint (after taking weights, sweep-out variables and
standardization into account) with the residual vector.
}
\item{constrained.coefficients}{
the coefficients on the scale on which they are constrained.  Useful
as initial value for further fits.
}}
\details{
The residuals, fitted values, coefficients, and effects should be extracted
by the generic functions of the same name, rather than
by using the \code{[[]]} and the \code{$} operator.
}
\seealso{
\code{\link{l1ce}}, \code{\link{coefficients}}.
}
\keyword{classes}
\keyword{regression}
\keyword{methods}
% Converted by Sd2Rd version 1.21.

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: labels.l1ce.d,v 1.2 1999/12/01 05:11:03 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{labels.l1ce}
\alias{labels.l1ce}
\alias{labels.l1celist}
\title{`Labels' Method for `l1ce' and `l1celist' Objects}
\usage{
labels.l1ce(object, \dots)
labels.l1celist(object, \dots)
}
\arguments{
  \item{object}{fitted model of class \code{"l1ce"} or
    \code{"l1celist"}, respectively.}
  \item{\dots}{potentially further arguments passed to method.}
}
\description{
  This is a method for the \code{\link{labels}()} function for objects
  inheriting from class \code{l1ce} or \code{l1celist} (see
  \code{help(\link{l1ce.object})} and \code{help(\link{l1celist.object})}).
  See \code{\link{labels}} or \code{\link{labels.default}} for the
  general behavior of this function and for the interpretation of
  \code{object}.
}
\keyword{utilities}

\eof
\name{lasso-internal}
\alias{opt.covmat}
\alias{tib.covmat}
\title{Internal lasso functions}
\description{
  Internal lasso functions.
}
\usage{
opt.covmat(xtx, xtr, bound, Lagrangian)
tib.covmat(xtx, gen.inverse.diag, beta, Lagrangian)
}
\details{
  These are not (yet?) to be called by the user.
}
\keyword{internal}

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% --> ../COPYRIGHT for more details
\name{merge.formula}
\alias{merge.formula}
\title{Merge Formula With Right Hand Side of Second Formula}
\usage{
merge.formula(x, y, \dots)
}
\arguments{
  \item{x,y}{formulas.}
  \item{\dots}{potentially further arguments passed to methods.}
}
\description{
  This is method for formulas of the \code{\link[base]{merge}} generic
  function.  Here it is support for the function \code{\link{l1ce}} and
  not intended to be called directly by users.
}
\examples{
merge.formula(y ~ x1, ~ x2) ## ->  y ~ x1 + x2

f2 <- merge.formula(y ~ x1*x2, z ~ (x2+x4)^3)
f. <- merge.formula(y ~ x1*x2,   ~ (x2+x4)^3) # no LHS for 2nd term
f2
stopifnot(f2 == f.)
}
\keyword{utilities}

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: plot.l1celist.d,v 1.2 1999/11/30 06:14:16 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{plot.l1celist}
\alias{plot.l1celist}
\title{Plot Method for `l1celist' Objects}
\description{
   Plots a \code{l1celist} object on the current graphics device.
}
\usage{
plot.l1celist(x, plot=TRUE, all=TRUE, constrained=FALSE,
              type = "b", xlab = "bounds", ylab = "coeff | bounds", \dots)
}
\arguments{
  \item{x}{fitted model object of class \code{l1celist}.}
  \item{plot}{logical; if \code{TRUE} a \code{matplot()} of all the
    coefficients in the list against the relative bound (absolute bound if
    relative is not present) is plotted.  Otherwise no plot is done.
  }
  \item{all}{logical; if \code{FALSE}, then only the non-zero
    coefficients are returned.}
  \item{constrained}{
    if \code{TRUE} then only the coefficients that were constrained
    are returned.}
 \item{type, xlab, ylab, \dots}{further arguments with useful defaults
   passed to \code{\link{matplot}}.}
}
\value{
  A matrix with the bound(s) (relative [if used] and absolute),
  the Lagrangian(s) and coefficints of the fitted model(s).
}
\examples{
data(Prostate)
l1c.P <- l1ce(lpsa ~ ., Prostate, bound=(1:20)/20)
length(l1c.P)# 20 l1ce models
plot(l1c.P)
}
\keyword{hplot}


\eof
\name{predict.gl1ce}
\alias{predict.gl1ce}
\title{Prediction Method for a `gl1ce' Object}
\description{
  This is a method for the generic function \code{\link{predict}}
  for class \code{"gl1ce"}, typically produced from
  \code{\link{gl1ce}()}.  When \code{newdata} is missing, the
  fitted values are extracted, otherwise returns \emph{new} predictions.
}
\usage{
\method{predict}{gl1ce}(object, newdata, type=c("link", "response"),
              se.fit = FALSE, \dots)
}
\arguments{
  \item{object}{a fitted \code{\link{gl1ce}} object.}
  \item{newdata}{
    a data frame containing the values at which predictions are required.
    This argument can be missing, in which case predictions are made at
    the same values used to compute the object.
    Only those predictors referred to in the right side of the formula in
    object need be present by name in \code{newdata}.}
  \item{type}{type of predictions, with choices "link" (the default), or
    "response".  The default produces predictions on the scale of the
    additive predictors, and with \code{newdata} missing,
    \code{predict()} is simply an extractor function for this component
    of a \code{gl1ce} object.  If "response" is selected, the
    predictions are on the scale of the response, and are monotone
    transformations of the additive predictors, using the inverse link
    function.}
  \item{se.fit}{logical indicating if standard errors should be returned
    as well. \bold{Not yet available}.}
  \item{\dots}{further potential arguments passed to methods.}
}
\value{
  a vector of predictions.
}
\section{Warning}{
  \code{predict} can produce incorrect predictions when the \code{newdata}
  argument is used if the formula in \code{object} involves
  data-dependent transformations, such as \code{poly(Age, 3)}
%% MM: this was for S-plus -- which has such problems with glm() -- maybe not R
  or \code{sqrt(Age - min(Age))}.
}
\examples{
  ## start with
  example(gl1ce)
  predict(gl1c.E, new = esoph[1:7,])# type 'link'
  predict(gl1c.E, new = esoph[1:7,], type = "response")

  ## identities / consistency checks :
  stopifnot(predict(gl1c.E, type = "response") == fitted(gl1c.E),
            all.equal(predict(gl1c.E)[1:7],
                      predict(gl1c.E, new = esoph[1:7,])),
            all.equal(fitted(gl1c.E)[1:7],
                      predict(gl1c.E, new = esoph[1:7,], type = "response"))
           )
}
\keyword{models}


\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: predict.l1ce.d,v 1.1 1998/09/18 07:27:59 bturlach Exp $
%
% This library is free software; you can redistribute it and/or
% modify it under the terms of the GNU Library General Public
% License as published by the Free Software Foundation; either
% version 2 of the License, or (at your option) any later version.
%
% This library is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% Library General Public License for more details.
%
% You should have received a copy of the GNU Library General Public
% License along with this library; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston,
% MA 02111-1307 USA
\name{predict.l1ce}
\alias{predict.l1ce}
\title{Predict Method for `l1ce' Objects}
\description{
  This is a method for the generic function \code{\link{predict}}
  for class \code{"l1ce"}, typically produced from
  \code{\link{l1ce}()}.  When \code{newdata} is missing, the
  fitted values are extracted, otherwise returns \emph{new} predictions.
}
\usage{
\method{predict}{l1ce}(object, newdata,
           type = c("response"), se.fit = FALSE, \dots)
}
\arguments{
  \item{object}{a fitted \code{l1ce} object.  }
  \item{newdata}{
    a data frame containing the values at which predictions are required.
    This argument can be missing, in which case predictions are made at
    the same values used to compute the object.
    Only those predictors referred to in the right side of the formula in
    object need be present by name in \code{newdata}.}
  \item{type}{currrently only \code{"response"}.}
  \item{se.fit}{logical indicating if standard errors should be returned
    as well. \bold{Not yet available}.}
  \item{\dots}{further potential arguments passed to methods.}
}
\value{
  a vector of predictions.
}
\section{Warning}{
  \code{predict} can produce incorrect predictions when the \code{newdata}
  argument is used if the formula in \code{object} involves
  transformations, such as \code{poly(Age, 3)} or \code{sqrt(Age - min(Age))}.

  MM: Not sure this is true for \R \ldots.
}
\examples{
data(Iowa)
l1c.I <- l1ce(Yield ~ ., Iowa, bound = 10, absolute.t=TRUE)
p10 <- predict(l1c.I, newdata =   Iowa[10:19,])
stopifnot(all.equal(p10, fitted(l1c.I)[10:19]))
}
\keyword{models}






\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: print.l1ce.d,v 1.2 1999/12/01 05:11:22 bturlach Exp $
\name{print.l1ce}
\alias{print.l1ce}
\alias{print.l1celist}
\alias{print.gl1ce}
\title{Print Methods for `l1ce', `l1celist' and `gl1ce' Objects}
\usage{
print.l1ce(x, \dots)
print.l1celist(x, \dots)
print.gl1ce(x, \dots)
}
\arguments{
  \item{x}{fitted model of class \code{"l1ce"} or
    \code{"l1celist"}, respectively.}
  \item{\dots}{potentially further arguments passed to method.}
}
\description{
  These are methods of the generic \code{\link{print}()} function for objects
  inheriting from class \code{l1ce}, \code{l1celist} or \code{gl1ce} (see
  \code{help(\link{l1ce.object})}, \code{help(\link{l1celist.object})}
  or \code{help(\link{gl1ce.object})}).  See \code{\link{print}} or
  \code{\link{print.default}} for the general behavior of this
  function.
}
\keyword{print}

\eof
\name{qr.rtr.inv}
\alias{qr.rtr.inv}
\title{Reconstruct the Inverse of R'R from a QR Object}
\description{
  From a QR object, compute the inverse matrix which is implicitely (but
  not explicitly!) used to solve the underlying least squares problem.
}
\usage{
qr.rtr.inv(qr)
}
\arguments{
  \item{qr}{\"qr\" object, typically resulting from \code{\link{qr}(.)}.}
}
\value{
  The \eqn{p \times p}{p * p} matrix \eqn{(R'R)^{-1}}{(R'R)^(-1)}
  or equivalently, the inverse of \eqn{X'X} (i.e. \code{t(X) \%*\% X} in \R).
}
\seealso{\code{\link{qr}}, \code{\link{qr.R}}, \code{\link{backsolve}}.}
\examples{
(h3 <- 1/outer(0:5, 1:3, "+"))
rtr <- qr.rtr.inv(qr(h3))
all.equal(c(rtr \%*\% 1:3), solve(crossprod(h3), 1:3))
}
\keyword{algebra}
\keyword{array}

\eof
\name{residuals.gl1ce}
\alias{residuals.gl1ce}
\title{Compute Residuals for `gl1ce' Objects}
\description{
  Computes one of the four types of residuals available for \code{gl1ce}
  objects.  This is a method for the function residuals() for  objects
  inheriting from class \code{gl1ce}.  As several types of residuals are
  available for \code{gl1ce} objects, there is an additional optional
  argument type.
}
\usage{
\method{residuals}{gl1ce}(object,
      type=c("deviance", "pearson", "working", "response"), \dots)
}
\arguments{
  \item{object}{
    an object inheriting from class \code{gl1ce} representing a fitted model.
  }
  \item{type}{
    type of residuals, with choices "deviance",  "pearson", "working" or
    "response"; the first is the default.
  }
 \item{\dots}{possibly further arguments (none at the moment).}
}
\value{
  A numeric vector of residuals. See Statistical Models in S for detailed
  definitions of each type of residual. The sum of squared deviance residuals
  add up to the deviance.  The pearson residuals are standardized residuals on
  the scale of the response.  The  working residuals reside on the
  object, and are the residuals from the final fit. The response residuals are
  simply  \code{y - fitted(object)}.  The \code{summary()} method for
  \code{gl1ce} objects produces deviance residuals.  The residuals
  component of a \code{gl1ce} object contains the working residuals.
}
\references{
  Chambers,  J.M.,  and  Hastie,  T.J.  (1991).  Statistical Models in S,
  pp. 204--206.
}
\seealso{\code{\link{gl1ce}} for examples;
  \code{\link{fitted.l1ce}} is used for fitted values.
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: residuals.l1ce.d,v 1.2 1999/12/01 05:11:45 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{residuals.l1ce}
\alias{residuals.l1ce}
\alias{residuals.l1celist}
\title{Residuals of `l1ce' or `l1celist' Objects}
\usage{
residuals.l1ce(object, type, \dots)
residuals.l1celist(object, type, \dots)
}
\arguments{
  \item{object}{
    an object inheriting from class \code{l1ce} representing a fitted model.
  }
  \item{type}{
    type of residuals, with choices "deviance",  "pearson", "working" or
    "response"; the first is the default.
  }
 \item{\dots}{possibly further arguments (none at the moment).}
}
\description{
  This is a method for the function \code{\link{residuals}} for objects
  inheriting from class \code{l1ce} or \code{l1celist} (see
  \code{help(\link{l1ce.object})} and \code{help(\link{l1celist.object})}).
  See \code{\link{residuals}} or \code{\link{residuals.default}} for the
  general behavior of this function and for the interpretation of
  \code{object} and \code{type}.
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
\name{summary.gl1ce}
\alias{summary.gl1ce}
\alias{print.summary.gl1ce}
\title{Summary Method for Generalized L1 Constrained Regression Models}
\description{
  Returns (and prints) a summary list for fitted generalized L1
  constrained regression models.
}
\usage{
\method{summary}{gl1ce}(object, dispersion = NULL, correlation = FALSE, \dots)
\method{print}{summary.gl1ce}(x, digits = max(3, getOption("digits") - 3), \dots)
}
\arguments{
  \item{object}{
    fitted \code{gl1ce} model object.  This is assumed to be the
    result of some fit that produces an object inheriting from
    the class \code{gl1ce}, in the sense that the components returned
    by the gl1ce() function will be available.
  }
  \item{dispersion}{prescribed dispersion, see \code{\link{summary.glm}}.}
  \item{correlation}{logical indicating if the correlation matrix should
    be returned as well.}
  \item{x}{object of class \code{summary.gl1ce}.}
  \item{digits, \dots}{further arguments for the \code{print} method.}
}
\value{
  an object of class \code{summary.gl1ce} (for which there's a
  \code{print} method).
  It is basically a list with the following components:

  \item{call}{as contained on object}
  \item{residuals}{the deviance residuals, as produced by
    \code{residuals(object, type = "deviance")}.}
  \item{coefficients}{the coefficients of the model.}
  \item{family}{
    the family of models to which object belongs, along with the
    variance and link functions for that model.}
  \item{bound}{the bound used in fitting this model}
  \item{Lagrangian}{the Lagrangian of the model}
}
\details{
  This function is a method for the generic function summary for  class
  \code{gl1ce}.
  It can be invoked by calling summary for an object of the appropriate class,
  or directly by calling  summary.gl1ce  regardless of the class of the object.
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: summary.l1ce.d,v 1.2 1998/09/27 02:02:02 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{summary.l1ce}
\alias{summary.l1ce}
\alias{print.summary.l1ce}
\title{Summary Method for ``l1ce'' Objects (Regression with L1 Constraint)}
}
\description{
  Returns a summary list for a regression model with an L1 constraint on
  the parameters.  A null value will be returned if printing is invoked.
}
\usage{
\method{summary}{l1ce}(object, correlation = TRUE,
         type = c("OPT", "Tibshirani"),
         gen.inverse.diag = 0, sigma = NULL, \dots)
\method{print}{summary.l1ce}(x, digits = max(3, getOption("digits") - 3), \dots)
}
\arguments{
  \item{object}{fitted model of class \code{"l1ce"}.}
  \item{correlation}{logical indicating if the correlation matrix for
    the coefficients should be included in the summary.}
  \item{type}{character string specifying
    whether to use the covariance formula of Osborne, Presnell and Turlach
    or the formula of Tibshirani.}
  \item{gen.inverse.diag}{
    if Tibshirani's formula for the covariance matrix is used, this value
    is used for the diagonal elements of the generalised inverse that
    appears in the formula that corresponds to parameters estimated to be
    zero.  The default is 0, i.e. use the Moore-Penrose inverse.
    Tibshirani's code uses gen.inverse.diag=1e11.}
  \item{sigma}{
    the residual standard error estimate.  If not provided, then it is
    estimated by the deviance of the model divided by the error degrees of
    freedom.}
  \item{x}{an \R object of class \code{summary.l1ce}.}
  \item{digits}{number of significant digits to use.}
  \item{\dots}{further potential arguments passed to methods.}
}
\value{
  an object of class \code{summary.l1ce} (for which there's a
  \code{print} method).
  It is basically a list with the following components:

  \item{correlation}{the computed correlation coefficient matrix for the
    coefficients in the model.}
  \item{cov.unscaled}{the unscaled covariance matrix; i.e, a matrix such
    that multiplying it by an estimate of the error variance produces an
    estimated covariance matrix for the coefficients.
  }
  \item{df}{the number of degrees of freedom for the model and for residuals.}
  \item{coefficients}{a matrix with three columns, containing the
    coefficients, their standard errors and the corresponding t statistic.}
  \item{residuals}{the model residuals.  These are the weighted
    residuals if weights were given in the model.}
  \item{sigma}{the residual standard error estimate.}
  \item{terms}{the terms object used in fitting this model.}
  \item{call}{the call object used in fitting this model.}
  \item{bound}{the bound used in fitting this model.}
  \item{relative.bound}{the relative bound used in fitting this model
    (may not be present).}
  \item{Lagrangian}{the Lagrangian of the model.}
}
\details{
  This function is a method for the generic function
  \code{\link{summary}()} for class \code{"l1ce"}.
  It can be invoked by calling \code{summary(x)} for an
  object \code{x} of the appropriate class, or directly by
  calling \code{summary.l1ce(x)} regardless of the
  class of the object.
}
\seealso{
  \code{\link{l1ce}}, \code{\link{l1ce.object}}, \code{\link{summary}}.
}
\examples{%%- or just those in ./l1ce.Rd
data(Prostate)
summary(l1ce(lpsa ~ .,Prostate))

# Produces the following output:
\dontrun{
Call:
 l1ce(formula = lpsa ~ ., data = Prostate)
Residuals:
    Min      1Q Median    3Q  Max
 -1.636 -0.4119  0.076 0.452 1.83


Coefficients:
             Value Std. Error Z score Pr(>|Z|)
(Intercept) 0.7285 1.3898     0.5242  0.6002
     lcavol 0.4937 0.0919     5.3711  0.0000
    lweight 0.2682 0.1774     1.5115  0.1307
        age 0.0000 0.0111     0.0000  1.0000
       lbph 0.0093 0.0587     0.1581  0.8744
        svi 0.4551 0.2525     1.8023  0.0715
        lcp 0.0000 0.0947     0.0000  1.0000
    gleason 0.0000 0.1685     0.0000  1.0000
      pgg45 0.0002 0.0046     0.0391  0.9688


Residual standard error: 0.7595 on 88.36 degrees of freedom
The relative L1 bound was      : 0.5
The absolute L1 bound was      : 0.9219925
The Lagrangian for the bound is:  13.05806


Correlation of Coefficients:
        (Intercept)  lcavol lweight     age    lbph     svi     lcp gleason
 lcavol  0.1988
lweight -0.4815     -0.2071
    age -0.3938     -0.0603 -0.0974
   lbph  0.3629     -0.0201 -0.5165 -0.1303
    svi -0.0624     -0.2273 -0.1442  0.0635  0.0648
    lcp  0.0457     -0.4153  0.0598  0.0665  0.0632 -0.3779
gleason -0.7666     -0.2009  0.1163 -0.0774 -0.0617  0.1084 -0.0243
  pgg45  0.4988      0.0956 -0.0380 -0.0630 -0.1111 -0.1921 -0.2935 -0.6526
}
}
\keyword{regression}
% Converted by Sd2Rd version 1.21.

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: tr.d,v 1.1 1998/12/18 06:41:47 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{tr}
\alias{tr}
\title{Trace of a Matrix}
\description{Calculates the trace of a matrix}
\usage{
tr(mat)
}
\arguments{
  \item{mat}{a square matrix.}
}
\value{
The trace of the matrix, i.e. the sum of its diagonal elements, is returned.
}
\examples{
tr(cbind(1,1:3,4:2)) # 5
}
\keyword{math}
% Converted by Sd2Rd version 1.21.

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: vcov.l1ce.d,v 1.2 1999/12/01 05:11:56 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{vcov.l1ce}
\alias{vcov.l1ce}
\alias{vcov.l1celist}
\title{Variance-Covariance Matrix of `l1ce' or `l1celist' Objects}
\usage{
\method{vcov}{l1ce}(object, type = c("OPT", "Tibshirani"),
    gen.inverse.diag = 0, \dots)
\method{vcov}{l1celist}(object, type = c("OPT", "Tibshirani"),
    gen.inverse.diag = 0, \dots)
}
\arguments{
  \item{object}{an object of class \code{l1ce} or \code{l1celist}.}
  \item{type}{character indicating whether to use the covariance formula
    of Osborne, Presnell and Turlach or the formula of Tibshirani.}
  \item{gen.inverse.diag}{if Tibshirani's formula for the covariance
    matrix is used, this value is used for the diagonal elements of the
    generalised inverse that appears in the formula that corresponds to
    parameters estimated to be zero.  The default is 0, i.e. use the
    Moore-Penrose inverse.  Tibshirani's code uses
    \code{gen.inverse.diag = 1e11}.}
  \item{\dots}{further potential arguments passed to methods.}
}
\description{
  This is a method for the function \code{vcov()} for objects inheriting
  from class \code{l1ce} or \code{l1celist} (see
  \code{help(\link{l1ce.object})} and
  \code{help(\link{l1celist.object})}).  See \code{\link{vcov}} for the
  general behavior of this function.
}
\keyword{models}
% Converted by Sd2Rd version 1.21.

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: aux.d,v 1.1 1998/09/18 11:12:48 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{aux}
\alias{aux}
\title{Extract Auxiliary Information From an Object}
\description{
  Generic function for extracting auxiliary information from fitted
  model objects.
}
\usage{
aux(object, \dots)
}
\arguments{
  \item{object}{fitted model object (here typically of class
    \code{l1celist}, see \code{\link{aux.l1celist}}).}
  \item{\dots}{potentilly further arguments passed to methods.}
}
\value{
  a matrix with the bound(s) (relative [if used] and absolute) and
  the Lagrangian(s) for the fitted model(s).
}
\details{
  See documentation (technical reports).
}
\keyword{utilities}

\eof
% Copyright (C) 1998
% Berwin A. Turlach <bturlach@stats.adelaide.edu.au>
% Bill Venables <wvenable@stats.adelaide.edu.au>
% $Id: aux.l1celist.d,v 1.2 1999/12/01 05:08:22 bturlach Exp $
% --> ../COPYRIGHT for more details
\name{aux.l1celist}
\alias{aux.l1celist}
\title{Use `aux()' on a `l1celist' object}
\usage{
aux.l1celist(object, \dots)
}
\arguments{
  \item{object}{fitted model object (here typically of class
    \code{l1celist}).}
  \item{\dots}{potentilly further arguments passed to methods.}
}
\description{
  This is a method for the function \code{aux()} for objects inheriting
  from class \code{l1celist}.
  See \code{\link{aux}} for the general behavior of this function
  and for the interpretation of \code{object}.
}
\keyword{utilities}
% Converted by Sd2Rd version 1.21.

\eof
